<?php

/* Reminder: always indent with 4 spaces (no tabs). */
 
/**
 * The MVCnPHP command interface
 */
require_once 'Geeklog/MVCnPHP/CommandInterface.php';

/**
 * Base command on which all other commands are built on
 *
 * This class provides some basic utility methods to the children of this class
 *
 * @author Tony Bibbs <tony@geeklog.net>
 * @copyright 2005 DVRS
 *
 */
abstract class PHPARCH_BaseCommand implements MVCnPHP_CommandInterface {
	/**
	 * Converts data submitted via the request into domain objects
	 *
	 * This function can be quite handy as it will convert form-based data over to domain objects
	 * granted your form field names adhere to the strict standard of <domainobject>-><property>. 
	 * So, for example, if you have a form field named GL2User->username this method will create
	 * a GL2User object and set the username.  
	 *
	 * A more powerful feature of this method is it can take an array of existing domain objects 
	 * that already have their data set and instead of creating new Propel domain objects it will
	 * use the ones you passed it and it will call the setters on those.  The beauty of this is 
	 * it will eliminate the need for you to call any of the setters on the domain object in your 
	 * command.
	 *
	 * @author Tony Bibbs <tony@geeklog.net>
	 * @access protected
	 * @param array $objInstance You can pass in pre-existing propel objects
	 * @return array Collection of domain objects
	 * @todo This function is currently unsophisticated.  More features may be added to this to do 
	 * things like allow associated one domain object as a property on another domain object.  
	 * Until we have a need I'll simply leave this method as is
	 *
	 */
	protected function requestToObjects($objInstances=array())
	{
	    if (!is_array($objInstances)) {
	        $objInstances = array();
	    }
	    
		// Gets the field names from the request
		$postVars = array_keys($_REQUEST);
		
		// Determine the name of the objects we need to create and the setters we'll need to call
		foreach ($postVars as $curVarName) {
			if (stristr($curVarName, '->')) {
				$tmpArray = explode('->',$curVarName);
				if (strstr($tmpArray[0],'_')) {
				    $nameOfClass = explode('_',$tmpArray[0]);
				    $nameOfClass = $nameOfClass[0];
				} else {
				    $nameOfClass = $tmpArray[0];
				}
				$objArray[$tmpArray[0]]['_NAME_OF_CLASS_'] = $nameOfClass;
				$objArray[$tmpArray[0]][$tmpArray[1]] = $_REQUEST[$curVarName];
			}
		}
		$objNames = @array_keys($objArray);
		
        // Now create each object and set the appropriate properties
        if(is_array($objNames)){
        	foreach ($objNames as $curObj) {		    
        		if (empty($objInstances[$curObj])) {
        		    $classToCreate = $objArray[$curObj]['_NAME_OF_CLASS_'];
        			//$obj = new $curObj();
        			$obj = new $classToCreate();
        			$objInstances[$curObj] = $obj;
        		} else {
        			$obj = $objInstances[$curObj];
        		}
        		$objAttributes = array_keys($objArray[$curObj]);
        		foreach ($objAttributes as $curAttribute) {
        		    if ($curAttribute <> '_NAME_OF_CLASS_') {
        		    	try {
            				$fnName = 'set' . ucwords($curAttribute);
            				$obj->$fnName($objArray[$curObj][$curAttribute]);
        		    	} catch(Exception $e) {
                            $_SESSION['requestToObjectsErrors'][] = $fnName.'('.$objArray[$curObj][$curAttribute].') Error: Invalid Data.';
        		    	}
        		    }
        		}
        		$objInstances[$curObj] = $obj;
        	}
        }
		
        // Return the object(s) that were created
        return $objInstances;
	}
	
	/**
	 * Provided a slick way to unformat a phone number from within a MVC view or right in the Flexy
	 * template
	 *
	 * @author Tony Bibbs <tony@geeklog.net>
	 * @access public
	 * @param string $phoneNumber Phone number to strip special characters out of
	 * @return string unformatted phone number
	 *
	 */
	public function unFormatPhoneNumber($phoneNumber)
	{
	    // Let formatter class do the work
	    return ITO_Formatter::unformatPhoneNumber($phoneNumber);    	       
	}
	
	/**
	 * Provided a slick way to unformat a zip code from within a MVC view or right in the Flexy
	 * template
	 *
	 * @author Tony Bibbs <tony@geeklog.net>
	 * @access public
	 * @param string $zipCode Zip code to strip formatting for
	 * @return string unformatted zip code
	 *
	 */
	public function unFormatZipCode($zipCode)
	{	    
	    return ITO_Formatter::unformatZipCode($zipCode);
	}
}

?>