<?php

/* Reminder: always indent with 4 spaces (no tabs). */

/**
 * Base Command
 */
require_once 'BaseCommandUser.php';

/**
 * User domain object
 */
require_once 'PHPARCH/Account.php';

/**
 * PEAR's Exception class
 */
require_once 'PEAR/Exception.php';

/**
 * DAO factory
 */
require_once 'system/DataAccess/DAO.php';

/**
 * Login command
 *
 * @copyright 2005
 * @author Tony Bibbs <Tony Bibbs <tony@geeklog.net>>
 *
 */
class PHPARCH_SaveAccountCommand extends PHPARCH_BaseCommandUser {
    /**
     * Holds the account that we will attempt to save.
     * @var Account
     * @access private
     */
    private $account = null;
    
    /**
	 * Provides a slick method for authorizing a user has sufficient privileges to execute this
	 * command.
	 *
	 * @author Tony Bibbs <tony@geeklog.net>
	 * @access protected
	 * @return boolean True if the user can execute the command, otherwise false
	 *
	 */
    protected function authorizedToView()
    {
        if (!$this->user->getIsAdmin()) {
            return false;
        }
        return false;
    }
    
    public function execute()
	{		
	    // We will always have a contact in session, question will be whether or not it is new.
		$this->account = unserialize($_SESSION['account']);
		
		// Try getting the account ID
		$aid = $this->account->getAccountId();
		
		if (empty($aid)) {		    
		    // This is a new contact, go get it
		    $objs = $this->requestToObjects();		   
		} else {		
		    // This is an existing contact, let's get the updates from the form
    		$objs = $this->requestToObjects(
                array('Account'=>$this->account));
		}
          
		// Until requestToObjects can handle parent child references we have to do this
		$this->account = $objs['Account'];        
		
		// Now let's validate the data
		if (!$this->passesValidation()) return 'errors';
				
		// Load matching user record from the database.
		$dao = PHPARCH_DAO::singleton();
				
		try {
		  // Try saving.  NOTE: this one command will start a transaction, do an insert on the two
		  // address objects and then insert the contact before commiting to the database.
		  $retVal = $dao->save($this->account);
		} catch (Exception $e) {
		    unset($_SESSION['account']);
		    // Throw the exception back for now, this really should be handled here
		    throw $e;
		}
		        
		// Now that they are done with the object, remove it from session.
		unset($_SESSION['account']);
        		
		$_SESSION['MVC_MESSAGES'][] = 'Successfully saved the account!';
		
		// go to home page
		return 'success';
	}
	
	private function passesValidation()
	{
	    $isValid = true;
	    
	    // Check if we got a new password, if so, verify it
	    if (!empty($_POST['newPassword'])) {
	        if ($_POST['newPassword'] <> $_POST['confirmNewPassword']) {
	            // Passwords didn't match error out
	            $_SESSION['MVC_ERRORS']['password'][] = 'The passwords you gave did not match!';
	            $isValid = false;
	        }
	        
	        // Set the password if it validated ok.
	        if ($isValid) {
	            $this->account->setPassword($_POST['newPassword']);
	        }
	    }
	    return $isValid;
	}
}

?>