CREATE TABLE list_item (
  item_id int unsigned NOT NULL auto_increment,
  group_name varchar(50) NOT NULL,
  short_name varchar(50) NOT NULL,
  description varchar(128),
  is_enabled tinyint(1) NOT NULL DEFAULT 1,
  sort_order mediumint NOT NULL DEFAULT 0,
  PRIMARY KEY (item_id),
  INDEX (group_name),
  INDEX (short_name),
  INDEX (is_enabled)
) TYPE=INNODB;

CREATE TABLE address (
  address_id int unsigned NOT NULL auto_increment,
  line1 varchar(75),
  line2 varchar(75),
  city varchar(50),
  state_id int unsigned default null,
  zip_code varchar(9),
  PRIMARY KEY(address_id),
  INDEX (state_id),
  FOREIGN KEY (state_id) REFERENCES list_item(item_id),
  INDEX (zip_code)
) TYPE=INNODB;

CREATE TABLE account (
  account_id int unsigned NOT NULL auto_increment,
  username varchar(25) NOT NULL,
  password varchar(25) NOT NULL,
  last_name varchar(25) NOT NULL,
  first_name varchar(25) NOT NULL,
  is_enabled tinyint(1) unsigned NOT NULL default 1,
  is_admin tinyint(1) unsigned NOT NULL default 0,
  PRIMARY KEY (account_id),
  UNIQUE (username)
) TYPE=INNODB;

CREATE TABLE contact (
  contact_id int unsigned NOT NULL auto_increment,
  account_id int unsigned NOT NULL,
  first_name varchar(30),
  last_name varchar(30),
  nick_name varchar(30),
  primary_email varchar(75),
  secondary_email varchar(75),
  home_number varchar(10),
  work_number varchar(10),
  fax_number varchar(10),
  mobile_number varchar(10),
  pager_number varchar(10),
  home_address_id int unsigned,
  work_address_id int unsigned,
  birth_date datetime,
  internet_hompage varchar(75),
  notes text,
  PRIMARY KEY (contact_id),
  INDEX (account_id),
  FOREIGN KEY (account_id) REFERENCES account(account_id) ON DELETE CASCADE,
  INDEX (home_address_id),
  FOREIGN KEY (home_address_id) REFERENCES address(address_id),
  INDEX (work_address_id),
  FOREIGN KEY (work_address_id) REFERENCES address(address_id)
) TYPE=INNODB;

/* States */
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','AL','Alabama',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','AK','Alaska',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','AZ','Arizona',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','AR','Arkansas',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','CA','California',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','CO','Colorado',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','CT','Connecticut',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','DE','Delaware',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','DC','District of Columbia',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','FL','Florida',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','GA','Georgia',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','HI','Hawaii',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','ID','Idaho',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','IL','Illinois',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','IN','Indiana',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','IA','Iowa',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','KS','Kansas',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','KY','Kentucky',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','LA','Louisiana',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','ME','Maine',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','MD','Maryland',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','MA','Massachusetts',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','MI','Michigan',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','MN','Minnesota',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','MS','Mississippi',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','MO','Missouri',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','MT','Montana',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','NE','Nebraska',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','NV','Nevada',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','NH','New Hampshire',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','NJ','New Jersey',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','NM','New Mexico',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','NY','New York',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','NC','North Carolina',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','ND','North Dakota',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','OH','Ohio',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','OK','Oklahoma',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','OR','Oregon',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','PA','Pennsylvania',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','RI','Rhode Island',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','SC','South Carolina',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','SD','South Dakota',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','TN','Tennessee',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','TX','Texas',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','UT','Utah',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','VT','Vermont',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','VA','Virginia',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','WA','Washington',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','WV','West Virginia',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','WI','Wisconsin',1,0);
INSERT INTO list_item (group_name,short_name,description,is_enabled,sort_order) VALUES ('STATES','WY','Wyoming',1,0);