<?php

class MVCnPHP_Forward {
    const VIEW = 1;
    const COMMAND = 2; 
    const REDIRECT = 3;
    
    /**
     * Forward type
     * @var int
     * @access protected
     */
    protected $type = null;
    
    /**
     * Object ID
     * @var string
     * @access protected
     */
    protected $id = null;
    
    /**
     * Forward target
     * @var string
     * @access protected
     */
    protected $target = null;
    
    /**
     * Sets the forward type
     * 
     * Can be either MVCnPHP_Forward::VIEW, MVCnPHP_Forward::COMMAND or
     * MVCnPHP_Forward::REDIRECT.  See the class-level constants
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * @param int $forwardType Type of forward object
     *
     */
    public function setType($forwardType)
    {
        $this->type = $forwardType;
    }
    
    /**
     * Gets the forward type
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * @return int Forward type. See the class-level constants
     *
     */
    public function getType()
    {
        return $this->type;
    }
    
    /**
     * Sets the Id
     *
     * The ID is what the controller is given in the request to look up 
     * what to do next.
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * @param string $id Id for the object
     *
     */
    public function setId($id)
    {
        $this->id = $id;
    }
    
    /**
     * Gets the Id
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * @return string Object ID
     *
     */
    public function getId()
    {
        return $this->id;
    }
    
    /**
     * Sets the forward target
     *
     * The forward target maps directly to a command or view ID and identifies what object should
     * be given control.  In the case the forward is a redirect, this value will be the URL to go to
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * @param string $forwardTarget Forward target
     *
     */
    public function setTarget($forwardTarget)
    {
        $this->target = $forwardTarget;
    }
    
    /**
     * Gets the forward target
     *
     * The forward target maps directly to a command or view ID and identifies what object should
     * be given control.  In the case the forward is a redirect, this value will be the URL to go to
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * @return string Forward target
     *
     */
    public function getTarget()
    {
        return $this->target;
    }
}

?>