<?php

/**
 * MVCnPHP_Forward class
 */
require_once 'Forward.php';

class MVCnPHP_MVCObject {
    const VIEW = 1;
    const COMMAND = 2;    
    
    /**
     * Object type
     * @var int
     * @access protected
     */
    protected $type = null;
    
    /**
     * Object ID
     * @var string
     * @access protected
     */
    protected $id = null;
    
    /**
     * Name of the class that will handle processing of this request
     * @var string
     * @access protected
     */
    protected $className = null;
    
    /**
     * Collection of forward tied to this object
     * @var array
     * @access protected
     */
    protected $forwards = array();
    
    /**
     * Sets the object type
     * 
     * Can be either MVCnPHP_MVCOjbect::VIEW or MVCnPHP_MVCOjbect::COMMAND
     * See the class-level constants
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * @param int $objectType Type of MVC object (See class-level constants)
     *
     */
    public function setType($objectType)
    {
        $this->type = $objectType;
    }
    
    /**
     * Gets the object type
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * @return int Object type. See the class-level constants
     *
     */
    public function getType()
    {
        return $this->type;
    }
    
    /**
     * Sets the Id
     *
     * The ID is what the controller is given in the request to look up 
     * what to do next.
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * @param string $id Id for the object
     *
     */
    public function setId($id)
    {
        $this->id = $id;
    }
    
    /**
     * Gets the Id
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * @return string Object ID
     *
     */
    public function getId()
    {
        return $this->id;
    }
    
    /**
     * Sets the class name
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * @param string $className Name of the class 
     *
     */
    public function setClassName($className)
    {
        $this->className = $className;
    }
    
    /**
     * Gets the class name
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * @return string Name of the class
     *
     */
    public function getClassName()
    {
        return $this->className;
    }
    
    /**
     * Adds a forward to the object
     *
     * Views and commands can have any number of forwards associated with them.  This method allows
     * a forward to be tied to the object
     *
     * @author Tony Bibbs <tony@geekog.net>
     * @access public
     * @param MVCnPHP_Forward $forwardObject Forward to add to the collection of forwards
     *
     */
    public function addForward(MVCnPHP_Forward $forwardObject)
    {
        $this->forwards[$forwardObject->getId()] = $forwardObject;
    }
    
    /**
     * Returns the collection of forwards we have
     * 
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * @return array Array of forwards
     *
     */
    public function getForwards()
    {
        return $this->forwards;
    }
    
}

?>