<?php

require_once 'Geeklog/MVCnPHP/BaseView.php';

abstract class PHPArch_BaseView implements MVCnPHP_BaseView {
    /**
     * Base URL to be used in all links, images, etc
     * @access public
     * @var string
     */
    public $baseUrl = null;
    
    /**
     * Array of flexy options
     * @access private
     * @var array
     */
    private $options = null;
    
    /**
     * Title of this view
     * @access protected
     * @var string
     */
    public $pageTitle = null;
    
    /**
     * Indicates if we should show navigation or not
     * @access public
     * @var boolean
     */
    public $showNavigation = true;
    
    /**
     * Meta tags to put in the HTML <head> section
     * @access private
     * @var string
     */
    public $metaTags = null;  
    
    /**
	 * Sets the title for the HTML page being outputted
	 *
	 * @author Tony Bibbs <tony.bibbs@iowa.gov
	 * @access public
	 * @param string $pageTitle Title to give the page
	 * 
	 */
	public function setPageTitle($pageTitle)
	{
		$this->pageTitle = $pageTitle;
	}
	
	/**
	 * Returns the page title
	 *
	 * @author Tony Bibbs <tony.bibbs@iowa.gov>
	 * @access public
	 * @return boolean
	 *
	 */
	public function getPageTitle()
	{
	    return $this->pageTitle;
	}    
	
	/**
	 * Sets the keywords meta tags for the page
	 *
	 * @author Tony Bibbs <tony.bibbs@iowa.gov
	 * @access public
	 * @param string $metaTags Meta tags to assign to page
	 * 
	 */
	public function setMetaTags($metaTags)
    {
    	$this->metaTags = $metaTags;
    }
    
    /**
     * Returns the meta tags to show in the page
     *
     * @author Tony Bibbs <tony.bibbs@iowa.gov>
     * @access public
     * @return boolean
     *
     */
	public function getMetaTags()
	{
	    return $this->metaTags;
	}
	
	/**
     * Shows the page header
     *
     * @author Tony Bibbs <tony.bibbs@iowa.gov>
     * @access private
     * @param string $pageTitle Title of the page
     * @param boolean $showNavigation Indicates if the navigation bar should be displayed
     * @param string $metaTags String of XHTML meta tags specific to this page
     *
     */
    protected function showHeader(boolean $showNavigation = true)
    {
        $header = '<html><head>';        
        $this->showNavigation = $showNavigation;
    	if (empty($this->pageTitle)) {
    		$this->pageTitle = 'PHP Architect, Contact Manager: Page Not Named';    		
    	}
    	$header .= sprintf('<title>%s</title>',$this->pageTitle);
    	if (empty($this->metaTags)) {
    		$this->metaTags = '';    		
    	}
    	$header .= sprintf('<meta name="KEYWORDS" content="%s"/>',$this->metaTags);
    	$header .= '</head><body>';
    	if ($showNavigation) {
    	    $header .= '<table><tr><td>';
    	    $header .= $this->showNavigation();
    	    $header .= '</td><td>';
    	}
    }

    /**
     * Shows the page footer
     *
     * @author Tony Bibbs
     * @acces private
     *
     */
    protected function showFooter()
    {
        if ($this->showNavigation) {
            $footer = '</td></tr></table>';
        }
        $footer = '</body></html>';
    }
}

?>