<?php

/* Reminder: always indent with 4 spaces (no tabs). */

/**
 * PHPARCH - Contact Manager
 *
 * @author Tony Bibbs <tony@geeklog.net>
 * @copyright 2005
 * @version $Id:$
 *
 */

/**
 * Abstract class that knows how to handle active user sessions
 */
require_once 'BaseViewFlexyUser.php';

/**
 * The Propel Account model object
 */
require_once 'PHPARCH/Account.php';

/**
 * DAO factory
 */
require_once 'system/DataAccess/DAO.php';

/**
 * Confirms the user really wants to delete an account
 *
 * @author Tony Bibbs <tony@geeklog.net>
 *
 */
class PHPArch_ConfirmAccountDeleteView extends PHPARCH_BaseViewFlexyUser {
    /**
     * The account the user is trying to delete
     * @var Account
     * @access public
     */
    public $account = null;
    
    /**
	 * Provides a slick method for authorizing a user has sufficient privileges to execute this
	 * command.
	 *
	 * @author Tony Bibbs <tony@geeklog.net>
	 * @access protected
	 * @return boolean True if the user can execute the command, otherwise false
	 *
	 */
    protected function authorizedToView()
    {
        if (!$this->user->getIsAdmin()) {
            return false;
        }
        return true;
    }
    
    /**
     * Shows the login page
     *
     * If we don't have a user object, we show the login page.  Otherwise we forward  the user on
     * to the user home page
     *
     * @author Tony Bibbs <tony@geeklog.net>
     * @access public
     * 
     */
    function processView()
    {
        if (empty($_GET['aid'])) {
            throw new Exception('You must select an account before trying to delete it');
        }
        
        // Get handle to Data Access Object
        $dao = PHPARCH_DAO::singleton();
        
        // Try to retrieve the object
        $this->account = new Account();
        $this->account->setAccountId($_GET['aid']);
        $this->account = $dao->get($this->account);

        // Make sure we got a valid account object back.
        if (!is_object($this->account)) {
            throw new Exception('The account cannot be deleted because it does not exist');
        }
        
        //print_r($this); exit;
        // Give the confirmation.
        $this->setPageTitle('PHPARCH - Confirm Account Deletion');
        $this->showHeader(true);
        $this->flexyHandle->compile('ConfirmAccountDeletion.thtml');
        $this->flexyHandle->outputObject($this);
        $this->showFooter();
    }
}

?>